#!/bin/sh
#
# check_vmem - Nagios plugin to check virtual memory
# ARG1: warning level
# ARG2: critical level
# by Michael Tosch
#

set -f
PATH=/bin:/usr/bin:/usr/sbin:/sbin
export PATH

usage(){
  echo "Usage: $0 [WARN] [CRIT]"
  echo " [WARN] and [CRIT] are integers"
}

case ${1:--}${2:--} in
*-h*)
  echo "This plugin prints the % used virtual memory
"
  usage
  echo "Example: $0 80 90"
  exit 3
  ;;
*[!0-9]*)
  usage
  exit 3
  ;;
esac

warn=${1:-80}
crit=${2:-90}

used=0
case `uname` in
Linux)
  # deduct some cached data because it is easily reclaimable: f=2=50% f=1.51=66% f=1.33=75%
  # 17.06.2014 changed f=2 to f=1.51
  # 08.07.2015 RHEL7: free has a new format
  used=`free | awk '
NR==1 && $5~/buff.*cache/ {x=1} 
/^Mem/ {total+=$2; eused+=$2-$4-((x==1)?$6:($6+$7))/f}
/^Swap/ {total+=$2; eused+=$3}
END {print int(eused*100/total)}' f=1.51`
  ;;
SunOS)
  used=`swap -s | nawk '{print int($9*100/($11+$9))}'`
  ;;
HP-UX)
  used=`swapinfo | awk '{total+=$2; used+=$3} END {print int(used*100/total)}'`
  ;;
AIX)
  eval `swap -s | awk '{print "tswap="$3, "uswap="$7}'`
  used=`vmstat 1 1 | awk '
$3~/^[0-9]/ && $4~/^[0-9]/ {print int(($3+uswap)*100/($3+$4+tswap))}
' uswap="$uswap" tswap="$tswap"`
  ;;
*) echo "UNKNOWN OS `uname`"; exit 3
  ;;
esac

if [ $used -le $warn ]; then
  echo "VMEM OK: $used% used memory|vmem=${used}%;${warn};${crit};0;"
  exit 0
elif [ $used -gt $warn -a $used -le $crit ];then
  echo "VMEM WARNING: $used% used memory|vmem=${used}%;${warn};${crit};0;"
  exit 1
elif [ $used -gt $crit ]; then
  echo "VMEM CRITICAL: $used% used memory|vmem=${used}%;${warn};${crit};0;"
  exit 2
else
  echo "VMEM UNKNOWN: |vmem=${avail}%;${warn};${crit};0;"
  exit 3
fi
